@@ -2,12 +2,12 @@
 
 from nornir_f5.plugins.connections.f5 import (
     CONNECTION_NAME,
-    F5iControlREST,
+    F5RestClient,
     f5_rest_client,
 )
 
 __all__ = (
     "CONNECTION_NAME",
-    "F5iControlREST",
+    "F5RestClient",
     "f5_rest_client",
 )
